@@ -93,29 +93,42 @@ function(
     maxmass=max(isomat[,2]);
     len3<-length(samples[,1])
     result<-.C("mass",
-      as.double(samples[,1]),as.double(samples[,3]),as.integer(len3),
-      as.double(mztol*2),as.double(mzfrac*2),as.double(rttol[1]),as.double(rttol[2]),
-      as.integer(manyisos),                                                                               # 8
-      as.double(isomat[,2]),as.integer(isomat[,4]),as.double(maxmass),as.integer(isomat[,7]),             # 12
-      as.integer(entry),as.integer(ppm2),                                                                 # 14
-      as.integer(getit1a),as.integer(getit2a),as.integer(getit4a),as.integer(getit5a),as.integer(getit6a) # 19
-      , PACKAGE="nontarget"
+		as.double(samples[,1]),
+		as.double(samples[,3]),
+		as.integer(len3),
+		as.double(mztol*2),
+		as.double(mzfrac*2),
+		as.double(rttol[1]),
+		as.double(rttol[2]),
+		as.integer(manyisos), # 8
+		as.double(isomat[,2]),
+		as.integer(isomat[,4]),
+		as.double(maxmass),
+		as.integer(isomat[,7]), # 12
+		as.integer(entry),
+		as.integer(ppm2), # 14
+		as.integer(getit1a),
+		as.integer(getit2a),
+		as.integer(getit4a),
+		as.integer(getit5a),
+		as.integer(getit6a), # 19
+		PACKAGE="nontarget"
     )
     # generate outputs: ########################################################
     isomat[,4]<-result[10];
     # (1) which isotope? #######################################################
-    for(i in 1:(alls-1)){for(j in 1:entry){if(result[15][[1]][(i-1)*entry+j]!=0){getit1[i]<-paste(getit1[i],result[15][[1]][(i-1)*entry+j],sep="/")}}};
+    for(i in 1:(alls)){for(j in 1:entry){if(result[15][[1]][(i-1)*entry+j]!=0){getit1[i]<-paste(getit1[i],result[15][[1]][(i-1)*entry+j],sep="/")}}};
     # (2) from which peak? #####################################################
-    for(i in 1:(alls-1)){for(j in 1:entry){if(result[16][[1]][(i-1)*entry+j]!=0){getit2[i]<-paste(getit2[i],result[16][[1]][(i-1)*entry+j],sep="/")}}};
+    for(i in 1:(alls)){for(j in 1:entry){if(result[16][[1]][(i-1)*entry+j]!=0){getit2[i]<-paste(getit2[i],result[16][[1]][(i-1)*entry+j],sep="/")}}};
     # (3) to which peak? #######################################################
-    for(i in 1:(alls-1)){for(j in 1:entry){if(result[17][[1]][(i-1)*entry+j]!=0){getit4[i]<-paste(getit4[i],result[17][[1]][(i-1)*entry+j],sep="/")}}};
+    for(i in 1:(alls)){for(j in 1:entry){if(result[17][[1]][(i-1)*entry+j]!=0){getit4[i]<-paste(getit4[i],result[17][[1]][(i-1)*entry+j],sep="/")}}};
     # (4) tolerance: small or large? ###########################################
-    for(i in 1:(alls-1)){for(j in 1:entry){
+    for(i in 1:(alls)){for(j in 1:entry){
 		if(result[18][[1]][(i-1)*entry+j]==1){getit5[i]<-paste(getit5[i],"small",sep="/")};
 		if(result[18][[1]][(i-1)*entry+j]==2){getit5[i]<-paste(getit5[i],"large",sep="/")};
     }};
     # (5) charge level: ########################################################
-    for(i in 1:(alls-1)){for(j in 1:entry){if(result[19][[1]][(i-1)*entry+j]!=0){getit6[i]<-paste(getit6[i],result[19][[1]][(i-1)*entry+j],sep="/")}}};
+    for(i in 1:(alls)){for(j in 1:entry){if(result[19][[1]][(i-1)*entry+j]!=0){getit6[i]<-paste(getit6[i],result[19][[1]][(i-1)*entry+j],sep="/")}}};
     if(result[13][[1]]!=entry){cat("WARNING: entry overflow -> links missing! Decrease mztol? Increasy entry argument?")};
     rm(result);
     #dyn.unload(paste(.libPaths(),"/nontarget/temp/massCpp.dll",sep=""));
